"use client";

import { useRef, useState, useEffect } from "react";
import { useSubscribe } from "@/app/hooks";
import siteData from "@/app/site.config";
import Image from "next/image";
import heroImg from "@/app/assets/landing-img.jpg";

const emailRegex = new RegExp(
  "^[a-zA-Z0-9_.+-]+@[a-zA-Z0-9-]+.[a-zA-Z0-9-.]+$"
);

export const Hero = () => {
  const [msg, setMsg] = useState<string>("");
  const [showErrorMsg, setShowErrorMsg] = useState<boolean>(false);
  const [showLoading, setShowLoading] = useState<boolean>(false);
  const emailRef = useRef<HTMLInputElement>(null);
  const { subscribe, isError, isSuccess } = useSubscribe();

  useEffect(() => {
    if (isError) {
      setShowErrorMsg(true);
      setMsg(
        siteData.inputFeedback?.error ?? "An error has occurred. Try again."
      );
    } else if (isSuccess && siteData.confirmEmail) {
      setShowErrorMsg(false);
      setMsg(
        siteData.inputFeedback?.emailSuccess ??
          "Thanks for subscribing! Please check your email to confirm your subscription."
      );
    } else if (isSuccess && !siteData.confirmEmail) {
      setShowErrorMsg(false);
      setMsg(
        siteData.inputFeedback?.noEmailSuccess ?? "Thanks for subscribing!"
      );
    }
  }, [isError, isSuccess]);

  const handleClick = async () => {
    setShowLoading(true);
    setMsg("");
    const email = emailRef.current?.value;

    if (email && emailRegex.test(email)) {
      setShowErrorMsg(false);
      await subscribe(email);
    } else {
      setShowErrorMsg(true);
      setMsg(
        siteData.inputFeedback?.incorrectEmail ??
          "You have entered an incorrect email. Try again."
      );
    }

    setShowLoading(false);
  };

  return (
    <div className="hero min-h-screen">
      <div className="hero-content flex-row p-0">
        <Image
          src={heroImg}
          className="rounded-lg shadow-2xl hidden sm:block h-96 w-64"
          alt="Hero image"
        />
        <div className="sm:text-left text-center">
          <h1>The headline of your newsletter</h1>
          <p className="my-4">Some text</p>
          <div className="flex gap-3 sm:justify-normal sm:flex-row flex-col justify-center">
            <input
              type="text"
              placeholder="Your email"
              className="input input-bordered"
              ref={emailRef}
            />
            <button className="btn btn-primary" onClick={handleClick}>
              {showLoading ? (
                <span className="loading loading-spinner loading-sm"></span>
              ) : (
                "Subscribe"
              )}
            </button>
          </div>
          <p
            className={`text-sm mt-1.5 ${
              showErrorMsg ? "text-error" : "text-success"
            }`}
          >
            {msg}
          </p>
        </div>
      </div>
    </div>
  );
};
