import { Metadata } from "next";
import siteData from "../site.config";

interface PageMetadata {
  title?: string;
  description?: string;
  keywords?: string[];
  route?: string;
  ogImg?: string;
  ogDescription?: string;
}

export function genPageMetadata({
  title,
  description,
  keywords,
  route,
  ogImg,
  ogDescription,
}: PageMetadata): Metadata {
  return {
    title: title
      ? `${title} | ${siteData.siteName}`
      : `${siteData.title} | ${siteData.siteName}`,
    description: description || siteData.description,
    keywords: keywords || siteData.keywords,
    metadataBase: new URL(siteData.url),
    alternates: {
      canonical: route ? `/${route}` : "/",
    },
    openGraph: {
      title: title
        ? `${title} | ${siteData.siteName}`
        : `${siteData.title} | ${siteData.siteName}`,
      description: description || siteData.description,
      url: route ? `/${route}` : "/",
      siteName: siteData.siteName,
      images: [
        {
          url: ogImg || siteData.ogImg,
          alt: ogDescription || siteData.ogDescription,
        },
      ],
      locale: siteData.lang,
      type: "website",
    },
    twitter: {
      title: title
        ? `${title} | ${siteData.siteName}`
        : `${siteData.title} | ${siteData.siteName}`,
      description: description || siteData.description,
      images: [ogImg || siteData.ogImg],
    },
  };
}
